@@ -30,6 +30,8 @@ typedef struct _ProcData ProcData;
 #include <gconf/gconf-client.h>
 #include <glibtop/cpu.h>
 
+#include <time.h>
+
 #include "smooth_refresh.h"
 
 #include "load-graph.h"
@@ -41,8 +43,6 @@ enum
 	ACTIVE_PROCESSES
 };
 
-#define NCPUSTATES 4
-
 enum
 {
 	MIN_UPDATE_INTERVAL = 1 * 1000,
@@ -90,10 +90,12 @@ struct _ProcInfo
 	gchar		*status; /* shared, don't free it ! */
 	gchar		*security_context;
 
+	time_t		start_time;
 	guint64		cpu_time_last;
 
 	guint64		vmsize;
 	guint64		memres;
+	guint64		memwritable;
 	guint64		memshared;
 	unsigned long	memxserver;
 
@@ -170,9 +172,6 @@ struct _ProcData
 	GStringChunk	*users;
 
 
-	GMemChunk	*procinfo_allocator;
-
-
 	/* libgtop uses guint64 but we use a float because
 	   frequency is ~always == 100
 	   and because we display cpu_time as %.1f seconds
